Handbook - Muscle System Nonstriated Muscle
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

MUSCLE SYSTEM NONSTRIATED MUSCLE Click pictures for new window with figure and legend, click again for high resolution image
1 Nematode Nonstriated (Single Sarcomere) Muscle Unlike the obliquely striated somatic muscles, which contain several to many sarcomeres repeating in regular order in one cell, nematode nonstriated muscles have either one or a few well-structured sarcomeres or myofilament networks that are less well organized. This group of muscles, also referred to as single-sarcomere muscles, includes pharyngeal, stomatointestinal, anal sphincter, anal depressor, contractile gonadal sheath, and sex-specific muscles. (For more inforamtion, see also Pharynx, Intestine, Rectum and Anus, Male-specific Muscles, Somatic Gonad, Muscle System of the Male and Dauer Pharynx.) In those that contain a single sarcomere, such as pharyngeal, anal depressor, and vulval muscles, the attachment points of the single sarcomere are localized at the ends of the cells as half I bands ending in electron-dense attachments or hemiadherens junctions and connect the myofilaments to epithelium or basal lamina. In other nonstriated muscles where the myofilament network is less well organized, such as uterine muscle um2 and contractile gonadal sheath (see also Egg-laying Apparatus and Somatic Gonad), the filaments seem to be attached to the plasma membrane via randomly localized electron-dense attachments, similar to those found in vertebrate smooth muscle. 2 Pharyngeal Muscles This group is comprised of 20 cells located in eight distinct divisions, pm1–pm8, in the pharynx (MusFIG 17; PharynxAtlas). Each pharyngeal muscle (pm) division contains one to three muscle cells (see Alimentary System - Overview) and each division, except the most posterior one, has threefold radial symmetry. Pharyngeal muscle cells are thought to be myoepithelial because, along with arcade cells, they secrete the pharyngeal cuticle. Also, they have clearly defined apical regions adjacent to the lumen cuticle and are bound by zonula adherens junctions. Contraction of pharyngeal muscle cells in general serves to open the lumen. In the first five layers (pm1–pm5), radially oriented filaments attach medially to the cuticle of the lumen and laterally to the pharyngeal basal lamina by hemiadherens junctions (these are labeled “half-desmosomes” in Albertson and Thomson, 1976), which are characterized by an electron-dense deposit on the cytoplasmic face of the plasma membrane (Albertson and Thomson, 1976). pm6 has three posterior projections that extend into pm7, and filaments are excluded from the middle one of these projections. pm7 cells contain both radially and longitudinally oriented filaments that provide a longitudinal, aswell as a radial, component to the motion of the grinder teeth when they contract. Similar to pm1–pm5, pm8 has radially oriented filaments that attach to the lumenal cuticle and the pharyngeal basal lamina at their ends. All muscles except pm8 are innervated by pharyngeal motor neurons. pm8 does not receive any direct innervation from any of the motor neurons. However, pm8 makes gap junctions to mc3 cells, which are innervated by the M5 neuron (Albertson and Thomson, 1976; White, 1988) (see Alimentary System - Overview and Pharynx, see also Gap Junctions). MusFIG 17: Pharyngeal muscles have single sarcomeres. A. Schematic diagram of the pharyngeal muscles, which are organized into eight cell groups, pm1-pm8 (also called m1-m8) (Moerman and Fire, 1997). Indicated are the approximate location and shape of individual cells, as seen from the left lateral side. (Purple) Pharyngeal MC cells. B. Epifluorescent image of pharyngeal muscles pm3-pm7 taken from a transgenic animal expressing the reporter gene C32F10.8::GFP. Muscles occupy positions within the pharynx as indicated. pm1, pm2, and pm8 do not express this marker. (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) C. Ultrastructure of single sarcomeres of pharyngeal muscle. TEM image of a cross section of the pharyngeal isthmus from a level at the posterior of the nerve ring (small graphic inset, right). pm5 muscle cells, MC cells, and nerve cords (red) show threefold symmetry within the pharynx. Bar, 1 μm. (Image source: N2U [MRC] A194 8-11.) D. Each sarcomere of the pharyngeal muscle covers the radial length of the muscle cell, ending in a half I band (thin filaments) and electron-dense attachments (arrowheads) at each end. Thick filaments occupy the middle of each sarcomere. E. On the pseudocoelomic face, each sarcomere ends in an electron-dense attachment (arrowheads) to the pharyngeal basal lamina. On the lumenal side, half I bands attach to the cuticle through electron-dense attachments (arrowheads).
3 Stomatointestinal Muscles Stomatointestinal (SI) muscles are two sheet-like cells that connect the surfaces of the intestinal cells to the ventral body wall (MusFIG 18; MusMOVIE 3) (Bird and Bird, 1991; Avery and Thomas, 1997). Some longitudinally oriented filaments are located in the ventral regions of the cells, and their attachment structures toward the intestine probably resemble the vertebrate smooth muscle as randomly placed along the cell length (White et al., 1986). Thin, flat processes of these cells wrap around the posterior regions of the intestine on the dorsal side. These processes contain a few vertically oriented myofilaments that attach to the dorsal body wall by hemiadherens junctions, just lateral to the dorsal body wall muscles. The stomatointestinal muscles send muscle arms to preanal ganglion where they receive synaptic input from DVB (direct input) and AVL (indirect input) neurons. They are electrically coupled to the anal sphincter and anal depressor muscles via gap junctions (see also Gap Junctions). Contraction of these muscles promotes defecation by pressurizing the intestinal contents near the posterior end of the intestine (see also Alimentary System - Intestine). MusFIG 18: Stomatointestinal muscles and anal depressor muscle. A. Graphic rendition of enteric (anal depressor, anal sphincter, and stomatointestinal) muscles, which function in defecation (from left lateral side). These three muscles are located at the tail just posteriorly to the intestine. They all receive direct innervation via muscle arms in the preanal ganglion region from the DVB neuron and indirect input from the AVL neuron, which makes gap junctions to DVB. B. A pair of stomatointestinal muscles wrap around the posterior of the intestine. The ventral portions of these muscles include some longitudinal, randomly arranged contractile filaments similar to vertebrate smooth muscle. The thin processes that encircle the posterior intestine contain myofilaments that attach to the body wall via electron-dense attachments (not shown). Epifluorescent image from a larval-stage transgenic animal expressing the reporter gene mig-2::GFP, left lateral view. (Image source: C. Kenyon and H. Thieringer.) C. The anal depressor muscle has a large, asymmetrically placed nucleus (arrow), close to the dorsal side of the H-shaped muscle, DIC image, left lateral view. D. The anal depressor muscle is a single sarcomeric muscle that attaches to the dorsal wall of the rectum on the ventral side and the dorsal hypodermis on the dorsal side. (Int) Intestine. Epifluorescent image from a transgenic animal expressing a GFP-tagged reporter gene in the anal depressor and anal sphincter muscles (toroidal portion out of plane of focus), left lateral view. (Strain source: Z.-W. Wang and B. Chen.) E. The myofilaments are organized as two parallel sheets on the right and left sides of the H-shaped anal depressor muscle. The single sarcomere of each sheet covers the length of the muscle. In this view, the thin filaments of the right side of the cell are in focus. Epifluorescent image from a transgenic animal expressing the reporter gene unc-27::GFP. (Strain source: L. Jia and S.W. Emmons.) MusMOVIE 3: 3-D reconstruction of (L) stomatointestinal muscle cell. 3-D movie was created from confocal images of a strain expressing the GFP marker linked to the promoter for D1081.2 using Zeiss LSM 5 Pascal software v. 3. (Image source: R. Newbury and D. Moerman.) Click on image to play movie. 4 Anal Depressor Muscle This is a large, single-sarcomere, H-shaped muscle in hermaphrodites that runs vertically between the dorsal wall of the rectum and the dorsal hypodermis (MusFIG 18 and MusFIG 19) (Thomas, 1990; Avery and Thomas, 1997). This muscle lifts the roof of the rectum when it contracts, allowing the rectum to fill during initial stages of defecation. Later, during defecation it relaxes and the contents of the rectum are expelled (Bird and Bird, 1991). The contractile elements are organized as two parallel sheets of filaments on the right and left sides of this cell, forming two vertically arranged, single sarcomeres. This muscle sends a long muscle arm to the preanal ganglion to be innervated by the DVB (directly) and AVL (indirectly) motor neurons (see also Alimentary System - Intestine). MusFIG 19: Ultrastructure of the anal depressor muscle. TEM cross section at the level of the anal depressor muscle. Each of the two vertically arranged, single sarcomeres ends in thin filaments, whereas the center of each sarcomere contains thick filaments. On the dorsal side, the half I bands of each myofilament sheet terminate in hemiadherens junctions (arrowheads in top panels of inset) that attach to the dorsal hypodermis just lateral to the dorsal muscle quadrants. On the ventral side, the half I bands attach to the rectal epithelium around the anal opening via hemiadherens junctions (arrowheads in bottom panel of inset). Hemidesmosomes in the rectal epithelial cell (arrows), in turn, function to link these myofilament attachments to the rectal cuticle. Bar, 1 μm. (Image source: B140 [Hall] 9550.)
This muscle is sexually dimorphic between hermaphrodite and male. In males, the contractile apparatus of the anal depressor detaches from the dorsal hypodermis and attaches to the dorsal spicule protractor during the L4 molt, completely reorienting the myofilaments to run anteroposteriorly instead of dorsoventrally (Male-specific Muscles) (Sulston and Horvitz, 1977; Sulston et al., 1980; White, 1988). 5 Anal Sphincter Muscle This is a single cell with a toroidal region encircling the proximal part of the rectum and about eight thin processes that radiate medially and laterally from this toroid. These include four long, filament-filled processes that extend laterally to anchor to the body wall on the dorsal and ventral sides (MusFIG 18 and MusFIG 20). The anal sphincter muscle circles the intestine at its junction with the rectum. During defecation, it is dilated before enteric muscle contractions occur to allow waste material to pass into the rectum. It then contracts nearly simultaneously with the other enteric muscles, possibly helping to squeeze the posterior intestine for expulsion of the waste (Reiner and Thomas, 1995; Avery and Thomas, 1997). The toroidal part of the muscle contains a continuous ring of contractile filaments, many of which do not seem to connect to any significant end-point attachment structures. In this aspect, it is thought to be similar to vertebrate smooth muscle (White, 1988). Filaments within the medially projecting, short processes occasionally show electron-dense attachments to the gland cells at the roof and floor of the rectal passageway (MusFIG 20) (see also Alimentary System - Intestine and Rectum and Anus). MusFIG 20: Anal sphincter muscle. A. The anal sphincter is located at the junction of the posterior intestine and the rectum (dotted lines). It includes a toroidal part that encircles the posterior end of the intestine and four thin processes that attach to the dorsal and ventral body wall (small arrow [ventral left process] arrowhead [toroidal section]). (White rectangle) Level of the section in B and C. Epifluorescent image from a transgenic animal expressing the reporter gene unc-68::GFP, left lateral view. Bar, 10μm. (Strain source: E. Maryon.) B&C. Cross section of the anal sphincter muscle, TEM image. B. High power. C. Low power. (Arrowheads) Circularly oriented contractile elements within the toroidal section (outlined in green in B). Many of these myofibrils have no obvious attachments, but some indent deeply into the rectal gland tissue inside a few short processes. (vir) Intestinal-rectal valve. The level of the section is indicated in C. Bar, 1 μm (Image source: JSE [MRC] 617-14.) D. Short, medially directed processes extend from the toroid. These contain filaments that show electron-dense attachments (white arrows) to the rectal gland cells near the intestinal-rectal valve, TEM image, transverse section. (Image source: JSE [MRC] 617-119.) This muscle is sexually dimorphic between hermaphrodite and male. In males, near the end of the L4 stage the muscle goes under a dramatic hypertrophy during the opening of a cloacal canal. In contrast to hermaphrodites and larval males, this modified sphincter must relax in males to permit defecation (see Male-specific Muscles) (Reiner and Thomas, 1995; Emmons and Sternberg, 1997). 6 Vulval Muscles The two sets of vulval muscles are vm1 and vm2, and each set contains four muscle cells with single sarcomeres (MusFIG 21). Both vulval and uterine muscles in the hermaphrodite are born at the late-L3 stage from two sex myoblasts, M.vlpaa and M.vrpaa. Through three consecutive divisions, each sex myoblast generates two sets (vm and um) of four daughters, with a total of 16 cells located around the developing vulva by the L3 molt. Eight of these comprise the vulval muscles. The four vm1 muscles insinuate between rows of ventral body wall muscles and run between the dorsal edge of the ventral body wall muscle quadrant and the vulC and vulD toroids of vulva (White et al., 1986). The four vm2 muscles run between the ventral margin of the body wall muscle quadrants and the uterus–vulva junction (between the uterus and vulF toroid). Hence, vm1 cells attach to the vulva more ventrally than do vm2 and are more superficial (Sulston and Horvitz, 1977). The single sarcomeres of each vulval muscle stretch along the entire muscle length and attach through hemiadherens junctions to discrete zones in the body wall on one end and to the vulval epithelium and vulval cuticle on the opposite end around the late-L4 stage (White, 1988). The nuclei of the sex muscles also settle into their final positions around the developing gonad at the L4 stage. Among vulval muscles, the vm2s are the only ones that are directly innervated by the VC and HSN neurons of the egg-laying circuitry. The other muscles are either directly or indirectly connected to vm2 by gap junctions (see also Gap Junctions). vm2s send muscle arms to a local neuropil on either side of the hypodermal ridge to receive synaptic input (White, 1988). Coordinated contraction of the vulval muscles expands the uterus and pulls the vulval lips apart, opening the passage for eggs to be expelled (Hodgkin, 1988) (see also Reproductive System - Egg-laying apparatus). Nematodes missing all eight vulval muscles are unable to lay eggs (Bird and Bird, 1991). MusFIG 21: Vulval and uterine muscles.There are two sets of vulval (vm1 and vm2) and uterine (um1 and um2) muscles with four cells in each set. A. Vulval muscles are single sarcomeric. Each vulval muscle attaches to the vulval toroid epithelium on one end and body wall on the opposite end via hemiadherens junctions. A single sarcomere traverses the length of each muscle cell between the body wall and the vulval epithelium. Half I bands end in hemiadherens junctions, whereas the thick filaments occupy the middle region. (Asterisk) Remaining thick and thin filaments of the single sarcomere on the right side are out of plane of section. TEM, horizontal section. Bar, 1 μm. (Image source: MIT [E. Hartwieg and R.H. Horvitz] EH5358-5370.) B. Same image as in A, magnified. (Arrowheads) Hemiadherens junctions that anchor the thin (actin) filaments of the vulval muscle to the vulval epithelium. (Arrows) Hemidesmosomes within the vulval epithelium that may function to link the muscle attachments to the vulval cuticle. C. vm1, vm2, and um1 muscles in the adult hermaphrodite, ventral view. (Dotted lines) Level of the seam cells and ventral midline on this epifluorescent image taken from a transgenic animal expressing the reporter gene unc-27::GFP. (Strain source: L. Jia and S.W. Emmons.) 7 Uterine Muscles There are two sets of uterine muscles, um1 and um2, with four post-embryonically born muscle cells in each set. Each um1 cell makes a quarter of a circle that cups the proximal uterus on the ventral side and attaches to it close to the vulva (MusFIG 22). Dorsally, these cells attach to the lateral seam cells close to the utse-seam attachment sites (Vogel and Hedgecock, 2001; Woo et al., 2004). In each half (left and right sides) uterus, the distal sets of uterine muscle cells (um2) make half circles that wrap around the uterus and attach to it in a region further from the vulva (Sulston and Horvitz, 1977). The filaments of the uterine muscles are circumferentially oriented, which, when the muscle contracts, may move eggs through the uterus by a squeezing action (Sulston and Horvitz, 1977). This myofilament network seems to be anchored to the thin basal lamina on the surface facing the uterus by randomly placed attachment points, similar to the distribution of the dense bodies in vertebrate smooth muscles (MusFIG 1D). There is no direct innervation of the uterine muscles. Instead, they are coupled via gap junctions to vulval muscles (White et al., 1986) (see also Reproductive System - Egg-laying apparatus and Gap Junctions). Nematodes missing all eight uterine muscles are still able to lay eggs, as has been shown by ablation studies (Bird and Bird, 1991). MusFIG 22: Uterine muscles of the hermaphrodite. A. Each um1 cell is single sarcomeric and attaches to the uterus close to the vulva on the ventral side and to the lateral seam cells close to the utse cell-seam attachment sites on the dorsal side. These cells encircle the ventral half of the proximal uterus on either side of the vulva. More distal from the vulva, each arm of the uterus is encircled by a pair of the distal set of uterine muscle cells (um2). um2 muscles may have more diffuse filament anchorages along the uterine basal lamina. (Image source: R. Lints.) B&C. Epifluorescent images from transgenic animals expressing the reporter gene unc-27::GFP. B. (Dotted line) Ventral midline, ventral view. C. (Dotted lines) Ventral midline and seam cell positions, ventral oblique view. (Strain source: L. Jia and S.W. Emmons.) D. Epifluorescent image from an adult transgenic animal expressing the reporter gene F54A5.3a::GFP, left lateral view. (Arrowheads) utse cells. (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) 8 Contractile Gonad Sheath of the Hermaphrodite Five pairs of gonadal sheath cells have stereotyped positions along the proximal–distal axis of the gonad and cover the germ-line tissue of each gonadal arm (see MusFIG 17 and Reproductive System - Somatic gonad). Sheath cell pairs 3, 4, and 5 abundantly express muscle filament components such as actin and myosin that are organized into dense networks (Hirsh et al., 1976; Strome, 1986; Goetinck and Waterston, 1994; McCarter et al., 1997; Hall et al., 1999). Filaments are predominantly longitudinally oriented in pairs 3 and 4 and both longitudinally and circumferentially oriented in pair 5 (MusFIG 18). Filaments are also present in sheath cells 1 and 2, but are much less abundant. The myofilament network of the contractile gonadal sheath is possibly similar in organization to that of vertebrate smooth muscle. Anchorage points for the myofilament lattice are distributed diffusely over the outward-facing cell surface. Each connects to the nearby basal lamina by an electron-dense attachment on the plasma membrane. During ovulation, contraction of the proximal sheath pulls the dilated spermatheca over the most proximal oocyte and hence transfers this oocyte into the spermatheca for fertilization. The sheath is not innervated. Instead, it contracts periodically, possibly in response to recurrent intracellular Ca++ transient currents (Bui and Sternberg, 2002, and references therein) (see Reproductive System - Somatic gonad). Gap junctions connect the sheath cells to one another, and transitory gap junctions connect the sheath to the primary oocyte (Hall et al., 1999) (see also Gap Junctions). Thus, signals between the germ line and sheath may coordinate sheath contractions to events in the oocyte and to the presence of sperm (McCarter et al., 1999; Miller et al., 2001; 2003). MusFIG 23: Somatic gonad, lateral view. Differential interference contrast (DIC) microscopy image of an adult anterior gonad arm. The extent and location of mature somatic gonad tissues are indicated by the color overlay. Magnification, 400x. (Based on Kimble and Hirsh, 1979; McCarter et al., 1997.) MusFIG 24: Distal and proximal gonadal sheath cells have different characteristics.A. Epifluorescent image showing the anterior gonad arm of a lim-7::GFP transgenic adult hermaphrodite, lateral view, left side. Five pairs of sheath cells (numbered 1-5) cover the arm. The LIM-7::GFP signal is strong in sheath-cell pairs 1-3, weak in 4, and absent from 5. The approximate position of sheath-cell borders is indicated by the dotted line. (N) Nucleus; (PG) proximal gonad; (DG) distal gonad. Magnification, 400x. (Strain source: O. Hobert.) B. Epifluorescent image of an adult (dissected) gonad arm costained with DAPI (blue, cell nuclei) and rhodamine phalloidin (red, actin). Magnification, 400x. (Image source: D. Killian and E.J. Hubbard.) 9 List of Nonstriated Muscle Cells i. Pharyngeal muscles (pm); Note that in earlier publications these cells are labeled as "m"; m1, m2, m3 etc., here they are labeled "pm" for "pharyngeal muscle" (Avery L. and Thomas J. H., 1997) 1. First pharyngeal muscle ring; all fuse into one syncytium around hatching pm1DL pm1DR pm1L pm1R pm1VL pm1VR 2. Second pharyngeal muscle ring pm2DL; fuses with DR around hatching pm2DR; fuses with DL around hatching pm2L; fuses with VL around hatching pm2R; fuses with VR around hatching pm2VL; fuses with L around hatching pm2VR; fuses with R around hatching 3. Third pharyngeal muscle ring pm3DL; fuses with DR around hatching pm3DR; fuses with DL around hatching pm3L; fuses with VL around hatching pm3R; fuses with VR around hatching pm3VL; fuses with L around hatching pm3VR; fuses with R around hatching 4. Fourth pharyngeal muscle ring pm4DL; fuses with DR around hatching pm4DR; fuses with DL around hatching pm4L; fuses with VL around hatching pm4R; fuses with VR around hatching pm4VL; fuses with L around hatching pm4VR; fuses with R around hatching 5.Fifth pharyngeal muscle ring pm5DL; fuses with DR around hatching pm5DR; fuses with DL around hatching pm5L; fuses with VL around hatching pm5R; fuses with VR around hatching pm5VL; fuses with L around hatching pm5VR; fuses with R around hatching 6. Sixth pharyngeal muscle ring pm6D pm6VL pm6VR 7. Seventh pharyngeal muscle ring pm7D pm7VL pm7VR 8. Eighth pharyngeal muscle ring pm8 ii. Enteric muscles 1. Stomatointestinal muscle mu intL; ABplpppppaa mu intR; MSppaapp 2. Anal sphincter muscle mu sph; ABprpppppap 3. Anal depressor muscle mu anal; ABplpppppap iii. Hermaphrodite sex muscles 1. vm1 M.vrpaapaa M.vrpaaapp M.vlpaapaa M.vlpaaapp 2. vm2 M.vrpaapap M.vrpaaapa M.vlpaapap M.vlpaaapa 3. um1 M.vrpaappa M.vrpaaaap M.vlpaappa M.vlpaaaap 3. um2 M.vrpaappp M.vrpaaaaa M.vlpaappp M.vlpaaaaa iv. Hermaphrodite contractile gonadal sheath 1. Somatic Sheath (10 cells/5 pairs) of anterior gonad arm: Z1.apa (sheath cell 1) Z1.appaaa (sheath cell 2) Z1.appaap (sheath cell 3) Z1.appapa (sheath cell 4) Z1.appapp (sheath cell 5) Z1.paaa (sheath cell 1) Z1.paapaaa (sheath cell 2) Z1.paapaap (sheath cell 3) Z1.paapapa (sheath cell 4) Z1.paapapp (sheath cell 5) 2. Somatic Sheath (10 cells/5 pairs) of posterior gonad arm: Z4.pap (sheath cell 1) Z4.paappp (sheath cell 2) Z4.paappa (sheath cell 3) Z4.paapap (sheath cell 4) Z4.paapaa (sheath cell 5) Z4.appp (sheath cell 1) Z4.appappp (sheath cell 2) Z4.appappa (sheath cell 3) Z4.appapap (sheath cell 4) Z4.appapaa (sheath cell 5) 10 References Albertson, D.G. and Thomson, J.N. 1976. The pharynx of Caenorhabditis elegans. Phil. Trans. Royal Soc. London 275B: 299-325. Article Avery D.G. and Thomas, J.H. 1997. Feeding and defecation. In C. elegans Volume II. Ed.s Riddle D.L., Blumenthal, T., Meyer B.J. and Priess J.R . Pp 679-716. Cold Spring Harbor Laboratory Press. Article Bird, A.F. and Bird, J. 1991. The structure of nematodes. Academic Press, San Diego, CA. Bui, Y.K. and Sternberg, P.W. 2002. Caenorhabditis elegans inositol 5-phosphatase homolog negatively regulates inositol 1,4,5-triphosphate signaling in ovulation. Mol. Biol. Cell 13: 1641-1651. Article Emmons, S.W. and Sternberg, P.W. 1997. Male Development and Mating Behavior. In C. elegans II (ed. D. L. Riddle et al.). Chapter 12. pp.295-334. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Goetinck, S. and Waterston, R.H. 1994. The Caenorhabditis elegans muscle-affecting gene unc-87 encodes a novel thin filament-associated protein. J .Cell Biol. 127: 79-93. Article Hall, D. H., Winfrey, V. P., Blaeuer, G., Hoffman, L. H., Furuta, T., Rose, K. L., Hobert, O., Greenstein, D. 1999. Ultrastructural features of the adult hermaphrodite gonad of Caenorhabditis elegans: relations between the germ line and soma. Dev Biol. 212: 101-123. Article Hirsh, D., Oppenheim, D. and Klass, M. 1976. Development of the reproductive system of Caenorhabditis elegans. Dev. Biol. 49: 200-219. Abstract Hodgkin, J. 1988. Sexual dimorphism and sex determination. In "The nematode C. elegans" (W. B. Wood ed.) pp243-280. Cold Spring Harbor Laboratory Press, New York. Abstract Kimble, J. and Hirsh, D. 1979. The postembryonic cell lineages of the hermaphrodite and male gonads in Caenorhabditis elegans. Dev. Biol. 70: 396-417. Article McCarter, J., Bartlett, B., Dang, T., and Schedl, T. 1997. Soma-germ cell interactions in Caenorhabditis elegans: multiple events of hermaphrodite germline development require the somatic sheath and spermathecal lineages. Dev. Biol. 181: 121-143. Article McCarter, J., Bartlett, B., Dang, T., and Schedl, T. 1999. On the control of oocyte meiotic maturation and ovulation in Caenorhabditis elegans. Dev. Biol. 205: 111-128. Article McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynski, B., Ha, E., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li, D., Mah, A., Marra, M., McGhee, J., Newbury, R., Pouzyrev, R., Riddle, D.L., Sonnhammer, E., Tian, H., Tu, D., Tyson, J.R., Vatcher, G., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quantit. Biol. 68: 159-69. Abstract Miller, M.A., Nguyen, V.Q., Lee, M.H., Kosinski, M., Schedl, T., Caprioli, R.M. and Greenstein, D. 2001. A sperm cytoskeletal protein that signals oocyte meiotic maturation and ovulation. Science 291: 2144-2147. Abstract Miller, M.A., Ruest, P.J., Kosinski, M., Hanks, S.K. and Greenstein, D. 2003. An Eph receptor sperm-sensing control mechanism for oocyte meiotic maturation in Caenorhabditis elegans. Genes Dev. 17: 187-200. Article Moerman, D.G. and Fire, A. 1997. Muscle: Structure, Function, and Development. In C. elegans Volume II. Ed.s Riddle D.L., T Blumenthal, BJ Meyer and JR Priess. Pp 417-470. Cold Spring Harbor Laboratory Press. Article Reiner, D.J. and Thomas, J.H. 1995. Reversal of a muscle response to GABA during C. elegans male development. J. Neurosci. 15: 6094-6102. Article Strome, S. 1986. Fluorescence visualization of the distribution of microfilaments in gonads and early embryos of the nematode Caenorhabditis elegans. J. Cell Biol. 103: 2241-2152. Article Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode, Caenorhabditis elegans. Dev. Biol. 56: 110–156. Article Sulston, J.E., Albertson, D.G. and Thomson, J.N. 1980. The Caenorhabditis elegans male: Postembryonic development of nongonadal structures. Dev Biol. 78: 542-576. Article Thomas, J.H. 1990. Genetic analysis of defecation in Caenorhabditis elegans. Genetics 124: 855-872. Article Vogel, B.E. and Hedgecock, E.M. 2001. Hemicentin, a conserved extracellular member of the immunoglobulin superfamily, organizes epithelial and other cell attachments into oriented line-shaped junctions. Development 128: 883–894. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode Caenorhabditis elegans. Phil. Trans. Roy. Soc. Lond. 314B: 1-340. Article White, J. 1988. The Anatomy. In The nematode C. elegans (ed. W.B. Wood). Chapter 4. pp 81-122. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Abstract Woo, W.M., Goncharov, A., Jin, Y. and Chisholm, A.D. 2004. Intermediate filaments are required for C. elegans epidermal elongation. Dev. Biol. 267: 216-229. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Muscle system, nonstriated muscle. In WormAtlas. doi:10.3908/wormatlas.1.8 Edited for the web by Laura A. Herndon. Last revision: April 23, 2013.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |